@@ -6,6 +6,7 @@ types: list[str] = [
     "AWS::ACMPCA::CertificateAuthority",
     "AWS::ACMPCA::CertificateAuthorityActivation",
     "AWS::ACMPCA::Permission",
+    "AWS::AIOps::InvestigationGroup",
     "AWS::APS::RuleGroupsNamespace",
     "AWS::APS::Scraper",
     "AWS::APS::Workspace",
@@ -957,6 +958,7 @@ types: list[str] = [
     "AWS::Redshift::Integration",
     "AWS::Redshift::ScheduledAction",
     "AWS::RedshiftServerless::Namespace",
+    "AWS::RedshiftServerless::Snapshot",
     "AWS::RedshiftServerless::Workgroup",
     "AWS::RefactorSpaces::Application",
     "AWS::RefactorSpaces::Environment",
@@ -1021,6 +1023,7 @@ types: list[str] = [
     "AWS::S3Outposts::Bucket",
     "AWS::S3Outposts::BucketPolicy",
     "AWS::S3Outposts::Endpoint",
+    "AWS::S3Tables::Namespace",
     "AWS::S3Tables::TableBucket",
     "AWS::S3Tables::TableBucketPolicy",
     "AWS::SDB::Domain",
@@ -1116,6 +1119,7 @@ types: list[str] = [
     "AWS::SecurityHub::DelegatedAdmin",
     "AWS::SecurityHub::FindingAggregator",
     "AWS::SecurityHub::Hub",
+    "AWS::SecurityHub::HubV2",
     "AWS::SecurityHub::Insight",
     "AWS::SecurityHub::OrganizationConfiguration",
     "AWS::SecurityHub::PolicyAssociation",
@@ -1229,6 +1233,9 @@ types: list[str] = [
     "AWS::WorkSpacesWeb::TrustStore",
     "AWS::WorkSpacesWeb::UserAccessLoggingSettings",
     "AWS::WorkSpacesWeb::UserSettings",
+    "AWS::WorkspacesInstances::Volume",
+    "AWS::WorkspacesInstances::VolumeAssociation",
+    "AWS::WorkspacesInstances::WorkspaceInstance",
     "AWS::XRay::Group",
     "AWS::XRay::ResourcePolicy",
     "AWS::XRay::SamplingRule",
@@ -1246,6 +1253,7 @@ cached: list[str] = [
     "aws-acmpca-certificateauthority.json",
     "aws-acmpca-certificateauthorityactivation.json",
     "aws-acmpca-permission.json",
+    "aws-aiops-investigationgroup.json",
     "aws-amazonmq-broker.json",
     "aws-amazonmq-configuration.json",
     "aws-amazonmq-configurationassociation.json",
@@ -1321,6 +1329,9 @@ cached: list[str] = [
     "aws-apprunner-service.json",
     "aws-apprunner-vpcconnector.json",
     "aws-apprunner-vpcingressconnection.json",
+    "aws-appstream-appblock.json",
+    "aws-appstream-appblockbuilder.json",
+    "aws-appstream-application.json",
     "aws-appstream-applicationentitlementassociation.json",
     "aws-appstream-applicationfleetassociation.json",
     "aws-appstream-directoryconfig.json",
@@ -1577,7 +1588,6 @@ cached: list[str] = [
     "aws-dms-replicationinstance.json",
     "aws-dms-replicationsubnetgroup.json",
     "aws-dms-replicationtask.json",
-    "aws-docdb-dbcluster.json",
     "aws-docdb-dbclusterparametergroup.json",
     "aws-docdb-dbinstance.json",
     "aws-docdb-dbsubnetgroup.json",
@@ -1739,7 +1749,6 @@ cached: list[str] = [
     "aws-events-apidestination.json",
     "aws-events-archive.json",
     "aws-events-connection.json",
-    "aws-events-endpoint.json",
     "aws-events-eventbus.json",
     "aws-events-eventbuspolicy.json",
     "aws-events-rule.json",
@@ -1760,6 +1769,7 @@ cached: list[str] = [
     "aws-fsx-storagevirtualmachine.json",
     "aws-fsx-volume.json",
     "aws-gamelift-alias.json",
+    "aws-gamelift-build.json",
     "aws-gamelift-fleet.json",
     "aws-gamelift-gameservergroup.json",
     "aws-gamelift-gamesessionqueue.json",
@@ -2056,6 +2066,7 @@ cached: list[str] = [
     "aws-mwaa-environment.json",
     "aws-neptune-dbcluster.json",
     "aws-neptune-dbclusterparametergroup.json",
+    "aws-neptune-dbinstance.json",
     "aws-neptune-dbparametergroup.json",
     "aws-neptune-dbsubnetgroup.json",
     "aws-neptune-eventsubscription.json",
@@ -2211,13 +2222,10 @@ cached: list[str] = [
     "aws-route53resolver-firewallrulegroup.json",
     "aws-route53resolver-firewallrulegroupassociation.json",
     "aws-route53resolver-outpostresolver.json",
-    "aws-route53resolver-resolverconfig.json",
     "aws-route53resolver-resolverdnssecconfig.json",
     "aws-route53resolver-resolverendpoint.json",
     "aws-route53resolver-resolverqueryloggingconfig.json",
     "aws-route53resolver-resolverqueryloggingconfigassociation.json",
-    "aws-route53resolver-resolverrule.json",
-    "aws-route53resolver-resolverruleassociation.json",
     "aws-rum-appmonitor.json",
     "aws-s3-accessgrant.json",
     "aws-s3-accessgrantsinstance.json",
@@ -2238,6 +2246,7 @@ cached: list[str] = [
     "aws-s3outposts-bucket.json",
     "aws-s3outposts-bucketpolicy.json",
     "aws-s3outposts-endpoint.json",
+    "aws-s3tables-namespace.json",
     "aws-s3tables-tablebucket.json",
     "aws-s3tables-tablebucketpolicy.json",
     "aws-sagemaker-app.json",
@@ -2284,6 +2293,7 @@ cached: list[str] = [
     "aws-securityhub-delegatedadmin.json",
     "aws-securityhub-findingaggregator.json",
     "aws-securityhub-hub.json",
+    "aws-securityhub-hubv2.json",
     "aws-securityhub-insight.json",
     "aws-securityhub-organizationconfiguration.json",
     "aws-securityhub-policyassociation.json",
@@ -2428,6 +2438,9 @@ cached: list[str] = [
     "aws-wafv2-webaclassociation.json",
     "aws-workspaces-workspace.json",
     "aws-workspaces-workspacespool.json",
+    "aws-workspacesinstances-volume.json",
+    "aws-workspacesinstances-volumeassociation.json",
+    "aws-workspacesinstances-workspaceinstance.json",
     "aws-workspacesthinclient-environment.json",
     "aws-workspacesweb-browsersettings.json",
     "aws-workspacesweb-dataprotectionsettings.json",
