@@ -6,6 +6,7 @@ types: list[str] = [
     "AWS::ACMPCA::CertificateAuthority",
     "AWS::ACMPCA::CertificateAuthorityActivation",
     "AWS::ACMPCA::Permission",
+    "AWS::AIOps::InvestigationGroup",
     "AWS::APS::RuleGroupsNamespace",
     "AWS::APS::Scraper",
     "AWS::APS::Workspace",
@@ -316,6 +317,10 @@ types: list[str] = [
     "AWS::GameLift::Alias",
     "AWS::GameLift::Build",
     "AWS::GameLift::Fleet",
+    "AWS::GlobalAccelerator::Accelerator",
+    "AWS::GlobalAccelerator::CrossAccountAttachment",
+    "AWS::GlobalAccelerator::EndpointGroup",
+    "AWS::GlobalAccelerator::Listener",
     "AWS::Glue::Classifier",
     "AWS::Glue::Connection",
     "AWS::Glue::Crawler",
@@ -528,6 +533,7 @@ types: list[str] = [
     "AWS::S3::BucketPolicy",
     "AWS::S3ObjectLambda::AccessPoint",
     "AWS::S3ObjectLambda::AccessPointPolicy",
+    "AWS::S3Tables::Namespace",
     "AWS::S3Tables::TableBucket",
     "AWS::S3Tables::TableBucketPolicy",
     "AWS::SDB::Domain",
@@ -614,6 +620,7 @@ cached: list[str] = [
     "aws-acmpca-certificateauthority.json",
     "aws-acmpca-certificateauthorityactivation.json",
     "aws-acmpca-permission.json",
+    "aws-aiops-investigationgroup.json",
     "aws-amazonmq-broker.json",
     "aws-amazonmq-configuration.json",
     "aws-apigateway-account.json",
@@ -709,7 +716,6 @@ cached: list[str] = [
     "aws-cloudfront-cloudfrontoriginaccessidentity.json",
     "aws-cloudfront-connectiongroup.json",
     "aws-cloudfront-continuousdeploymentpolicy.json",
-    "aws-cloudfront-distribution.json",
     "aws-cloudfront-distributiontenant.json",
     "aws-cloudfront-function.json",
     "aws-cloudfront-keygroup.json",
@@ -809,7 +815,6 @@ cached: list[str] = [
     "aws-ec2-subnetnetworkaclassociation.json",
     "aws-ec2-subnetroutetableassociation.json",
     "aws-ec2-trafficmirrorfilter.json",
-    "aws-ec2-trafficmirrorfilterrule.json",
     "aws-ec2-trafficmirrortarget.json",
     "aws-ec2-transitgateway.json",
     "aws-ec2-transitgatewayattachment.json",
@@ -852,6 +857,7 @@ cached: list[str] = [
     "aws-ecs-clustercapacityproviderassociations.json",
     "aws-ecs-primarytaskset.json",
     "aws-ecs-service.json",
+    "aws-ecs-taskdefinition.json",
     "aws-ecs-taskset.json",
     "aws-efs-accesspoint.json",
     "aws-efs-filesystem.json",
@@ -895,6 +901,10 @@ cached: list[str] = [
     "aws-fsx-snapshot.json",
     "aws-fsx-storagevirtualmachine.json",
     "aws-fsx-volume.json",
+    "aws-globalaccelerator-accelerator.json",
+    "aws-globalaccelerator-crossaccountattachment.json",
+    "aws-globalaccelerator-endpointgroup.json",
+    "aws-globalaccelerator-listener.json",
     "aws-glue-classifier.json",
     "aws-glue-connection.json",
     "aws-glue-customentitytype.json",
@@ -955,11 +965,13 @@ cached: list[str] = [
     "aws-lakeformation-tagassociation.json",
     "aws-lambda-alias.json",
     "aws-lambda-eventinvokeconfig.json",
+    "aws-lambda-eventsourcemapping.json",
     "aws-lambda-function.json",
     "aws-lambda-layerversion.json",
     "aws-lambda-layerversionpermission.json",
     "aws-lambda-permission.json",
     "aws-lambda-version.json",
+    "aws-launchwizard-deployment.json",
     "aws-location-apikey.json",
     "aws-location-geofencecollection.json",
     "aws-location-map.json",
@@ -978,14 +990,15 @@ cached: list[str] = [
     "aws-logs-querydefinition.json",
     "aws-logs-resourcepolicy.json",
     "aws-logs-subscriptionfilter.json",
-    "aws-logs-transformer.json",
     "aws-msk-batchscramsecret.json",
     "aws-msk-cluster.json",
     "aws-msk-clusterpolicy.json",
     "aws-msk-configuration.json",
     "aws-msk-vpcconnection.json",
+    "aws-mwaa-environment.json",
     "aws-neptune-dbcluster.json",
     "aws-neptune-dbclusterparametergroup.json",
+    "aws-neptune-dbinstance.json",
     "aws-neptune-dbparametergroup.json",
     "aws-neptune-dbsubnetgroup.json",
     "aws-neptune-eventsubscription.json",
@@ -1074,12 +1087,9 @@ cached: list[str] = [
     "aws-route53resolver-firewalldomainlist.json",
     "aws-route53resolver-firewallrulegroup.json",
     "aws-route53resolver-firewallrulegroupassociation.json",
-    "aws-route53resolver-resolverconfig.json",
     "aws-route53resolver-resolverendpoint.json",
     "aws-route53resolver-resolverqueryloggingconfig.json",
     "aws-route53resolver-resolverqueryloggingconfigassociation.json",
-    "aws-route53resolver-resolverrule.json",
-    "aws-route53resolver-resolverruleassociation.json",
     "aws-s3-accessgrant.json",
     "aws-s3-accessgrantsinstance.json",
     "aws-s3-accessgrantslocation.json",
@@ -1088,6 +1098,7 @@ cached: list[str] = [
     "aws-s3-bucketpolicy.json",
     "aws-s3objectlambda-accesspoint.json",
     "aws-s3objectlambda-accesspointpolicy.json",
+    "aws-s3tables-namespace.json",
     "aws-s3tables-tablebucket.json",
     "aws-s3tables-tablebucketpolicy.json",
     "aws-sagemaker-mlflowtrackingserver.json",
