@@ -910,6 +910,7 @@ types: list[str] = [
     "AWS::Redshift::Integration",
     "AWS::Redshift::ScheduledAction",
     "AWS::RedshiftServerless::Namespace",
+    "AWS::RedshiftServerless::Snapshot",
     "AWS::RedshiftServerless::Workgroup",
     "AWS::RefactorSpaces::Application",
     "AWS::RefactorSpaces::Environment",
@@ -963,6 +964,7 @@ types: list[str] = [
     "AWS::S3Outposts::Bucket",
     "AWS::S3Outposts::BucketPolicy",
     "AWS::S3Outposts::Endpoint",
+    "AWS::S3Tables::Namespace",
     "AWS::S3Tables::TableBucket",
     "AWS::S3Tables::TableBucketPolicy",
     "AWS::SDB::Domain",
@@ -1057,6 +1059,7 @@ types: list[str] = [
     "AWS::SecurityHub::DelegatedAdmin",
     "AWS::SecurityHub::FindingAggregator",
     "AWS::SecurityHub::Hub",
+    "AWS::SecurityHub::HubV2",
     "AWS::SecurityHub::Insight",
     "AWS::SecurityHub::OrganizationConfiguration",
     "AWS::SecurityHub::PolicyAssociation",
@@ -1183,6 +1186,9 @@ types: list[str] = [
     "AWS::WorkSpacesWeb::TrustStore",
     "AWS::WorkSpacesWeb::UserAccessLoggingSettings",
     "AWS::WorkSpacesWeb::UserSettings",
+    "AWS::WorkspacesInstances::Volume",
+    "AWS::WorkspacesInstances::VolumeAssociation",
+    "AWS::WorkspacesInstances::WorkspaceInstance",
     "AWS::XRay::Group",
     "AWS::XRay::ResourcePolicy",
     "AWS::XRay::SamplingRule",
@@ -1271,6 +1277,9 @@ cached: list[str] = [
     "aws-appmesh-virtualnode.json",
     "aws-appmesh-virtualrouter.json",
     "aws-appmesh-virtualservice.json",
+    "aws-appstream-appblock.json",
+    "aws-appstream-appblockbuilder.json",
+    "aws-appstream-application.json",
     "aws-appstream-applicationentitlementassociation.json",
     "aws-appstream-applicationfleetassociation.json",
     "aws-appstream-directoryconfig.json",
@@ -1335,7 +1344,6 @@ cached: list[str] = [
     "aws-budgets-budget.json",
     "aws-budgets-budgetsaction.json",
     "aws-cassandra-keyspace.json",
-    "aws-cassandra-table.json",
     "aws-cassandra-type.json",
     "aws-ce-anomalymonitor.json",
     "aws-ce-anomalysubscription.json",
@@ -1462,6 +1470,7 @@ cached: list[str] = [
     "aws-connect-view.json",
     "aws-connect-viewversion.json",
     "aws-connectcampaigns-campaign.json",
+    "aws-connectcampaignsv2-campaign.json",
     "aws-controltower-enabledbaseline.json",
     "aws-controltower-enabledcontrol.json",
     "aws-controltower-landingzone.json",
@@ -1503,6 +1512,7 @@ cached: list[str] = [
     "aws-datazone-owner.json",
     "aws-datazone-project.json",
     "aws-datazone-projectmembership.json",
+    "aws-datazone-projectprofile.json",
     "aws-datazone-subscriptiontarget.json",
     "aws-datazone-userprofile.json",
     "aws-detective-graph.json",
@@ -1541,6 +1551,7 @@ cached: list[str] = [
     "aws-ec2-customergateway.json",
     "aws-ec2-dhcpoptions.json",
     "aws-ec2-ec2fleet.json",
+    "aws-ec2-egressonlyinternetgateway.json",
     "aws-ec2-eip.json",
     "aws-ec2-eipassociation.json",
     "aws-ec2-enclavecertificateiamroleassociation.json",
@@ -1589,7 +1600,6 @@ cached: list[str] = [
     "aws-ec2-subnetnetworkaclassociation.json",
     "aws-ec2-subnetroutetableassociation.json",
     "aws-ec2-trafficmirrorfilter.json",
-    "aws-ec2-trafficmirrorfilterrule.json",
     "aws-ec2-trafficmirrorsession.json",
     "aws-ec2-trafficmirrortarget.json",
     "aws-ec2-transitgateway.json",
@@ -1637,6 +1647,7 @@ cached: list[str] = [
     "aws-ecs-clustercapacityproviderassociations.json",
     "aws-ecs-primarytaskset.json",
     "aws-ecs-service.json",
+    "aws-ecs-taskdefinition.json",
     "aws-ecs-taskset.json",
     "aws-efs-accesspoint.json",
     "aws-efs-filesystem.json",
@@ -1680,7 +1691,6 @@ cached: list[str] = [
     "aws-emr-studiosessionmapping.json",
     "aws-emr-walworkspace.json",
     "aws-emrcontainers-virtualcluster.json",
-    "aws-emrserverless-application.json",
     "aws-entityresolution-idmappingworkflow.json",
     "aws-entityresolution-idnamespace.json",
     "aws-entityresolution-matchingworkflow.json",
@@ -1815,6 +1825,7 @@ cached: list[str] = [
     "aws-iotevents-input.json",
     "aws-iotfleethub-application.json",
     "aws-iotsitewise-accesspolicy.json",
+    "aws-iotsitewise-asset.json",
     "aws-iotsitewise-assetmodel.json",
     "aws-iotsitewise-dashboard.json",
     "aws-iotsitewise-gateway.json",
@@ -1825,7 +1836,6 @@ cached: list[str] = [
     "aws-kafkaconnect-workerconfiguration.json",
     "aws-kendra-datasource.json",
     "aws-kendra-faq.json",
-    "aws-kendra-index.json",
     "aws-kendraranking-executionplan.json",
     "aws-kinesis-resourcepolicy.json",
     "aws-kinesis-stream.json",
@@ -2105,13 +2115,10 @@ cached: list[str] = [
     "aws-route53resolver-firewallrulegroup.json",
     "aws-route53resolver-firewallrulegroupassociation.json",
     "aws-route53resolver-outpostresolver.json",
-    "aws-route53resolver-resolverconfig.json",
     "aws-route53resolver-resolverdnssecconfig.json",
     "aws-route53resolver-resolverendpoint.json",
     "aws-route53resolver-resolverqueryloggingconfig.json",
     "aws-route53resolver-resolverqueryloggingconfigassociation.json",
-    "aws-route53resolver-resolverrule.json",
-    "aws-route53resolver-resolverruleassociation.json",
     "aws-rum-appmonitor.json",
     "aws-s3-accessgrant.json",
     "aws-s3-accessgrantsinstance.json",
@@ -2129,6 +2136,7 @@ cached: list[str] = [
     "aws-s3outposts-bucket.json",
     "aws-s3outposts-bucketpolicy.json",
     "aws-s3outposts-endpoint.json",
+    "aws-s3tables-namespace.json",
     "aws-s3tables-tablebucket.json",
     "aws-s3tables-tablebucketpolicy.json",
     "aws-sagemaker-app.json",
@@ -2174,6 +2182,7 @@ cached: list[str] = [
     "aws-securityhub-delegatedadmin.json",
     "aws-securityhub-findingaggregator.json",
     "aws-securityhub-hub.json",
+    "aws-securityhub-hubv2.json",
     "aws-securityhub-insight.json",
     "aws-securityhub-organizationconfiguration.json",
     "aws-securityhub-policyassociation.json",
@@ -2332,6 +2341,9 @@ cached: list[str] = [
     "aws-workspaces-connectionalias.json",
     "aws-workspaces-workspace.json",
     "aws-workspaces-workspacespool.json",
+    "aws-workspacesinstances-volume.json",
+    "aws-workspacesinstances-volumeassociation.json",
+    "aws-workspacesinstances-workspaceinstance.json",
     "aws-workspacesthinclient-environment.json",
     "aws-workspacesweb-browsersettings.json",
     "aws-workspacesweb-dataprotectionsettings.json",
