@@ -562,6 +562,7 @@ types: list[str] = [
     "AWS::Redshift::Integration",
     "AWS::Redshift::ScheduledAction",
     "AWS::RedshiftServerless::Namespace",
+    "AWS::RedshiftServerless::Snapshot",
     "AWS::RedshiftServerless::Workgroup",
     "AWS::Rekognition::Collection",
     "AWS::ResourceExplorer2::DefaultViewAssociation",
@@ -599,12 +600,15 @@ types: list[str] = [
     "AWS::S3::AccessPoint",
     "AWS::S3::Bucket",
     "AWS::S3::BucketPolicy",
+    "AWS::S3::MultiRegionAccessPoint",
+    "AWS::S3::MultiRegionAccessPointPolicy",
     "AWS::S3ObjectLambda::AccessPoint",
     "AWS::S3ObjectLambda::AccessPointPolicy",
     "AWS::S3Outposts::AccessPoint",
     "AWS::S3Outposts::Bucket",
     "AWS::S3Outposts::BucketPolicy",
     "AWS::S3Outposts::Endpoint",
+    "AWS::S3Tables::Namespace",
     "AWS::S3Tables::TableBucket",
     "AWS::S3Tables::TableBucketPolicy",
     "AWS::SDB::Domain",
@@ -739,6 +743,9 @@ types: list[str] = [
     "AWS::WAFv2::WebACL",
     "AWS::WAFv2::WebACLAssociation",
     "AWS::WorkSpaces::Workspace",
+    "AWS::WorkspacesInstances::Volume",
+    "AWS::WorkspacesInstances::VolumeAssociation",
+    "AWS::WorkspacesInstances::WorkspaceInstance",
     "AWS::XRay::Group",
     "AWS::XRay::ResourcePolicy",
     "AWS::XRay::SamplingRule",
@@ -868,7 +875,6 @@ cached: list[str] = [
     "aws-cloudfront-cloudfrontoriginaccessidentity.json",
     "aws-cloudfront-connectiongroup.json",
     "aws-cloudfront-continuousdeploymentpolicy.json",
-    "aws-cloudfront-distribution.json",
     "aws-cloudfront-distributiontenant.json",
     "aws-cloudfront-function.json",
     "aws-cloudfront-keygroup.json",
@@ -955,6 +961,7 @@ cached: list[str] = [
     "aws-ec2-customergateway.json",
     "aws-ec2-dhcpoptions.json",
     "aws-ec2-ec2fleet.json",
+    "aws-ec2-egressonlyinternetgateway.json",
     "aws-ec2-eip.json",
     "aws-ec2-eipassociation.json",
     "aws-ec2-flowlog.json",
@@ -994,7 +1001,7 @@ cached: list[str] = [
     "aws-ec2-subnetcidrblock.json",
     "aws-ec2-subnetnetworkaclassociation.json",
     "aws-ec2-subnetroutetableassociation.json",
-    "aws-ec2-trafficmirrorfilterrule.json",
+    "aws-ec2-trafficmirrorfilter.json",
     "aws-ec2-trafficmirrortarget.json",
     "aws-ec2-transitgateway.json",
     "aws-ec2-transitgatewayattachment.json",
@@ -1145,6 +1152,7 @@ cached: list[str] = [
     "aws-kinesis-stream.json",
     "aws-kinesisanalyticsv2-application.json",
     "aws-kms-alias.json",
+    "aws-kms-key.json",
     "aws-kms-replicakey.json",
     "aws-lakeformation-datacellsfilter.json",
     "aws-lakeformation-datalakesettings.json",
@@ -1187,6 +1195,7 @@ cached: list[str] = [
     "aws-mwaa-environment.json",
     "aws-neptune-dbcluster.json",
     "aws-neptune-dbclusterparametergroup.json",
+    "aws-neptune-dbinstance.json",
     "aws-neptune-dbparametergroup.json",
     "aws-neptune-dbsubnetgroup.json",
     "aws-neptune-eventsubscription.json",
@@ -1287,13 +1296,10 @@ cached: list[str] = [
     "aws-route53resolver-firewallrulegroup.json",
     "aws-route53resolver-firewallrulegroupassociation.json",
     "aws-route53resolver-outpostresolver.json",
-    "aws-route53resolver-resolverconfig.json",
     "aws-route53resolver-resolverdnssecconfig.json",
     "aws-route53resolver-resolverendpoint.json",
     "aws-route53resolver-resolverqueryloggingconfig.json",
     "aws-route53resolver-resolverqueryloggingconfigassociation.json",
-    "aws-route53resolver-resolverrule.json",
-    "aws-route53resolver-resolverruleassociation.json",
     "aws-rum-appmonitor.json",
     "aws-s3-accessgrant.json",
     "aws-s3-accessgrantsinstance.json",
@@ -1301,12 +1307,15 @@ cached: list[str] = [
     "aws-s3-accesspoint.json",
     "aws-s3-bucket.json",
     "aws-s3-bucketpolicy.json",
+    "aws-s3-multiregionaccesspoint.json",
+    "aws-s3-multiregionaccesspointpolicy.json",
     "aws-s3objectlambda-accesspoint.json",
     "aws-s3objectlambda-accesspointpolicy.json",
     "aws-s3outposts-accesspoint.json",
     "aws-s3outposts-bucket.json",
     "aws-s3outposts-bucketpolicy.json",
     "aws-s3outposts-endpoint.json",
+    "aws-s3tables-namespace.json",
     "aws-s3tables-tablebucket.json",
     "aws-s3tables-tablebucketpolicy.json",
     "aws-sagemaker-app.json",
@@ -1427,8 +1436,13 @@ cached: list[str] = [
     "aws-wafv2-ipset.json",
     "aws-wafv2-loggingconfiguration.json",
     "aws-wafv2-regexpatternset.json",
+    "aws-wafv2-rulegroup.json",
+    "aws-wafv2-webacl.json",
     "aws-wafv2-webaclassociation.json",
     "aws-workspaces-workspace.json",
+    "aws-workspacesinstances-volume.json",
+    "aws-workspacesinstances-volumeassociation.json",
+    "aws-workspacesinstances-workspaceinstance.json",
     "aws-xray-group.json",
     "aws-xray-resourcepolicy.json",
     "aws-xray-samplingrule.json",
