@@ -607,6 +607,7 @@ types: list[str] = [
     "AWS::Redshift::Integration",
     "AWS::Redshift::ScheduledAction",
     "AWS::RedshiftServerless::Namespace",
+    "AWS::RedshiftServerless::Snapshot",
     "AWS::RedshiftServerless::Workgroup",
     "AWS::ResilienceHub::App",
     "AWS::ResilienceHub::ResiliencyPolicy",
@@ -772,7 +773,6 @@ types: list[str] = [
 # pylint: disable=too-many-lines
 cached: list[str] = [
     "Module",
-    "aws-accessanalyzer-analyzer.json",
     "aws-acmpca-certificate.json",
     "aws-acmpca-certificateauthority.json",
     "aws-acmpca-certificateauthorityactivation.json",
@@ -965,6 +965,8 @@ cached: list[str] = [
     "aws-ec2-clientvpntargetnetworkassociation.json",
     "aws-ec2-customergateway.json",
     "aws-ec2-dhcpoptions.json",
+    "aws-ec2-ec2fleet.json",
+    "aws-ec2-egressonlyinternetgateway.json",
     "aws-ec2-eip.json",
     "aws-ec2-enclavecertificateiamroleassociation.json",
     "aws-ec2-flowlog.json",
@@ -998,11 +1000,12 @@ cached: list[str] = [
     "aws-ec2-securitygroupingress.json",
     "aws-ec2-securitygroupvpcassociation.json",
     "aws-ec2-snapshotblockpublicaccess.json",
+    "aws-ec2-spotfleet.json",
     "aws-ec2-subnet.json",
     "aws-ec2-subnetcidrblock.json",
     "aws-ec2-subnetnetworkaclassociation.json",
     "aws-ec2-subnetroutetableassociation.json",
-    "aws-ec2-trafficmirrorfilterrule.json",
+    "aws-ec2-trafficmirrorfilter.json",
     "aws-ec2-trafficmirrorsession.json",
     "aws-ec2-trafficmirrortarget.json",
     "aws-ec2-transitgateway.json",
@@ -1078,7 +1081,7 @@ cached: list[str] = [
     "aws-emr-securityconfiguration.json",
     "aws-emr-step.json",
     "aws-emrcontainers-virtualcluster.json",
-    "aws-emrserverless-application.json",
+    "aws-events-archive.json",
     "aws-events-eventbuspolicy.json",
     "aws-eventschemas-discoverer.json",
     "aws-eventschemas-registry.json",
@@ -1144,6 +1147,7 @@ cached: list[str] = [
     "aws-imagebuilder-infrastructureconfiguration.json",
     "aws-imagebuilder-workflow.json",
     "aws-inspectorv2-cisscanconfiguration.json",
+    "aws-inspectorv2-filter.json",
     "aws-iot-accountauditconfiguration.json",
     "aws-iot-authorizer.json",
     "aws-iot-billinggroup.json",
@@ -1166,6 +1170,7 @@ cached: list[str] = [
     "aws-iot-securityprofile.json",
     "aws-iot-softwarepackage.json",
     "aws-iot-softwarepackageversion.json",
+    "aws-iot-thing.json",
     "aws-iot-thinggroup.json",
     "aws-iot-thingprincipalattachment.json",
     "aws-iot-thingtype.json",
@@ -1181,6 +1186,7 @@ cached: list[str] = [
     "aws-kinesisvideo-signalingchannel.json",
     "aws-kinesisvideo-stream.json",
     "aws-kms-alias.json",
+    "aws-kms-key.json",
     "aws-kms-replicakey.json",
     "aws-lakeformation-datacellsfilter.json",
     "aws-lakeformation-datalakesettings.json",
@@ -1310,13 +1316,10 @@ cached: list[str] = [
     "aws-route53resolver-firewalldomainlist.json",
     "aws-route53resolver-firewallrulegroup.json",
     "aws-route53resolver-firewallrulegroupassociation.json",
-    "aws-route53resolver-resolverconfig.json",
     "aws-route53resolver-resolverdnssecconfig.json",
     "aws-route53resolver-resolverendpoint.json",
     "aws-route53resolver-resolverqueryloggingconfig.json",
     "aws-route53resolver-resolverqueryloggingconfigassociation.json",
-    "aws-route53resolver-resolverrule.json",
-    "aws-route53resolver-resolverruleassociation.json",
     "aws-s3-accessgrant.json",
     "aws-s3-accessgrantsinstance.json",
     "aws-s3-accessgrantslocation.json",
